/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

package com.fundi.framework.common.change;

import java.util.LinkedHashMap;
import java.util.Map;

import com.fundi.framework.common.displaylist.ListField;
import com.fundi.framework.common.displaylist.ListRow;

public class ListRowChangeableWrapper implements IChangeable {

	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$

	private	ListRow					source;
	private ChangeListScope			cls;
	
	public ListRowChangeableWrapper(ListRow	listRow) {
		this.source = listRow;
	}

	public ChangeListScope getChangeListScope() {
		return cls;
	}

	public void setChangeListScope(ChangeListScope cls) {
		this.cls = cls;
	}

	@Override
	public ListRow getSource() {
		return source;
	}

	/**
	 * used when this is the default item in the ChangeListScope
	 */
	@Override
	public boolean isRecognisedKey(Object key) {
		return source.getFieldByKeyLabel((String) key) != null;
	}

	@Override
	public String getInitialValue(Object key) {
		String		result;
		ListField	field;
		
		result = null;
		if (String.class.isInstance(key)) {
			field = source.getFieldByKeyLabel((String) key);
			if (field != null) {
				//leave ChangeListScope to handle asking for the default if a null is returned
				result = field.getValue();
			}
		}
		
		return (String) result;
	}

	@Override
	public String getFinalValue(Object key) {
		return (String) cls.getFinalValue(source, key);
	}

	/**
	 * Separation of concerns here -
	 * ChangeListScope understands change values and items, not that the items contain objects that contain values - so all reference to ListField is dealt
	 * with in this class.
	 */
	@Override
	public ListField getInitialObject(Object key) {
		ListField	field;
		
		field = null;
		if (String.class.isInstance(key)) {
			field = source.getFieldByKeyLabel((String) key);
		}
		if (field == null) {
			field = (ListField) cls.getDefaultItem().getInitialObject(key);
		}		
		return field;
	}

	@Override
	public ListField getFinalObject(Object key) {
		ListField	field;
		
		field = (ListField) getInitialObject(key);
		if (field == null) {
			field = (ListField) cls.getDefaultItem().getFinalObject(key);
		} else {
			field = new ListField(field.getDefn(), (String) getFinalValue(key));
		}
		
		return field;
	}

	@Override
	public Map<String, ListField> getChangedObjects() {
		Map<Object, Object>	changes;
		Map<String, ListField>	changedObjects;
		
		changedObjects = new LinkedHashMap<String, ListField>();
		changes = cls.getValues(); 
		for (Object key: changes.keySet()) {
			changedObjects.put((String) key, getFinalObject(key));
		}
		
		return changedObjects;
	}

}