package com.fundi.framework.common.cslcomms;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

import java.io.Serializable;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;

import com.fundi.framework.common.nl1.Messages;
import com.fundi.framework.common.util.StringEditor;

public class CSLFieldDefn implements Serializable {
	
	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$
	
	private static final long serialVersionUID = 1L;
	
	public static final String DTYPE_CHAR = Messages.getString("CSLFieldDefn_4"); //$NON-NLS-1$
	public static final String DTYPE_INT = Messages.getString("CSLFieldDefn_5"); //$NON-NLS-1$
	public static final String ALIGN_LEFT = Messages.getString("CSLFieldDefn_6"); //$NON-NLS-1$
	public static final String ALIGN_RIGHT = Messages.getString("CSLFieldDefn_7"); //$NON-NLS-1$
	
	private String keyLabel = ""; //$NON-NLS-1$
	private String slbl = ""; //$NON-NLS-1$
	private String llbl = "";  //$NON-NLS-1$
	private boolean key = false;
	private int keySeq = 0;
	private int len = -1;  //Value of -1 means "any length".
	private String dtype = DTYPE_CHAR;
	private String align = ALIGN_LEFT;
	private boolean compareIgnore = false;
	private boolean compareHide = false;

	public CSLFieldDefn() {
		
		super();
	}
	
	public CSLFieldDefn(String hdr) {
		
		//The hdr is a <hdr> object within a <cmdrsphdr> object.
		
		super();
		
		StringTokenizer parser;
		String token;
		String substituteDelim = "~"; //$NON-NLS-1$
		String tmpHdr;
		
		//Fiddle the hdr to replace all " plus space with "~, so we can tokenise without affecting labels containing a space or double quote.
		tmpHdr = hdr.substring(0, 4) + substituteDelim + hdr.substring(5).replace("\" ", "\"" + substituteDelim); //$NON-NLS-1$ //$NON-NLS-2$
		
		parser = new StringTokenizer(tmpHdr, substituteDelim); //$NON-NLS-1$
		try {
			while (parser.hasMoreTokens()) {
				token = parser.nextToken().trim();
				//The format of each token is label="value".  Strip off the trailing ".
				token = token.substring(0, token.length() - 1);
				if (token.startsWith(Messages.getString("CSLFieldDefn_11"))) { //$NON-NLS-1$
					slbl = token.substring(6);
				}
				if (token.startsWith(Messages.getString("CSLFieldDefn_12"))) {  //$NON-NLS-1$
					llbl = token.substring(6);
				}
				if (token.startsWith(Messages.getString("CSLFieldDefn_13"))) { //$NON-NLS-1$
					key = token.substring(5).equals(Messages.getString("CSLFieldDefn_14")); //$NON-NLS-1$
					keySeq = Integer.parseInt(token.substring(5));
				}
				if (token.startsWith(Messages.getString("CSLFieldDefn_15"))) { //$NON-NLS-1$
					if (token.substring(5).equals(Messages.getString("CSLFieldDefn_16"))) { //$NON-NLS-1$
						len = -1;
					}
					else {
						len = Integer.parseInt(token.substring(5));
					}
				}
				if (token.startsWith(Messages.getString("CSLFieldDefn_17"))) { //$NON-NLS-1$
					dtype = token.substring(7).toLowerCase();
				}
				if (token.startsWith(Messages.getString("CSLFieldDefn_18"))) { //$NON-NLS-1$
					align = token.substring(7).toLowerCase();
				}
				if (token.startsWith("fud:ignore=\"")) { //$NON-NLS-1$
					compareIgnore = token.substring(12).toLowerCase().equals("yes"); //$NON-NLS-1$
				}
				if (token.startsWith("fud:hide=\"")) { //$NON-NLS-1$
					compareHide = token.substring(10).toLowerCase().equals("yes"); //$NON-NLS-1$
				}
				if (token.startsWith("fud:keyLabel=\"")) { //$NON-NLS-1$
					keyLabel = token.substring(14);
				}
			}
		}
		catch (NoSuchElementException e) {}
	}

	public String getSlbl() {
		
		return slbl;
	}

	public String getLlbl() {
		
		return llbl;
	}

	public boolean isKey() {
		
		return (key && keySeq > 0);
	}
	
	public int getKeySeq() {
		
		return keySeq;
	}

	public int getLen() {
		
		return len;
	}

	public String getDtype() {
		
		return dtype;
	}

	public String getAlign() {
		
		return align;
	}
	
	public int getMaxLength() {
		
		return len;
	}

	public void setSlbl(String slbl) {
		this.slbl = slbl;
	}

	public void setLlbl(String llbl) {
		this.llbl = llbl;
	}

	public void setKey(boolean key) {
		this.key = key;
		if (key) {		
			keySeq = 1;
		}
		else {
			keySeq = 0;
		}
	}
	
	public void setKey(int keySeq) {
		
		key = (keySeq > 0);
		this.keySeq = keySeq;
	}

	public void setLen(int len) {
		this.len = len;
	}

	public void setDtype(String dtype) {
		this.dtype = dtype;
	}

	public void setAlign(String align) {
		this.align = align;
	}
	
	public boolean ignoreInCompare() {
		
		return compareIgnore;
	}
	
	public boolean hideInCompare() {
		
		return compareHide;
	}
	
	public boolean hideField() {
		
		return compareHide;  //fud:hide= parameter was changed via FUW-307 to mean hide in compare and hide in lists.
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((align == null) ? 0 : align.hashCode());
		result = prime * result + ((dtype == null) ? 0 : dtype.hashCode());
		result = prime * result + (key ? 1231 : 1237);
		result = prime * result + keySeq;
		result = prime * result + len;
		result = prime * result + ((llbl == null) ? 0 : llbl.hashCode());
		result = prime * result + ((slbl == null) ? 0 : slbl.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		CSLFieldDefn other = (CSLFieldDefn) obj;
		if (align == null) {
			if (other.align != null)
				return false;
		} else if (!align.equals(other.align))
			return false;
		if (dtype == null) {
			if (other.dtype != null)
				return false;
		} else if (!dtype.equals(other.dtype))
			return false;
		if (key != other.key)
			return false;
		if (len != other.len)
			return false;
		if (llbl == null) {
			if (other.llbl != null)
				return false;
		} else if (!llbl.equals(other.llbl))
			return false;
		if (slbl == null) {
			if (other.slbl != null)
				return false;
		} else if (!slbl.equals(other.slbl))
			return false;
		return true;
	}

	public String getKeyLabel() {
		if (keyLabel != null && !keyLabel.isEmpty()) {
			return keyLabel;
		} else {
			return llbl;
		}
	}

	public void setKeyLabel(String keyLabel) {
		this.keyLabel = keyLabel;
	}
}
