package com.fundi.framework.common.cslcomms;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

import java.io.Serializable;

import com.fundi.framework.common.nl1.Messages;

public class DRDResponse implements Serializable {

	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$
	
	private static final long serialVersionUID = 1L;
	private String response = "";  //$NON-NLS-1$
	private String returnCode = "";  //$NON-NLS-1$
	private String reasonCode = "";  //$NON-NLS-1$
	private String reasonMsg = "";  //$NON-NLS-1$
	private String reasonTxt = "";  //$NON-NLS-1$
	
	private Xheader xhdr = null;
	
	private static final String RSNMSG_START_TAG = Messages.getString("DRDResponse_9");  //$NON-NLS-1$
	private static final String RSNMSG_END_TAG = Messages.getString("DRDResponse_10");  //$NON-NLS-1$
	private static final String RC_START_TAG = Messages.getString("DRDResponse_11");  //$NON-NLS-1$
	private static final String RC_END_TAG = Messages.getString("DRDResponse_12");  //$NON-NLS-1$
	private static final String RSN_START_TAG = Messages.getString("DRDResponse_13");  //$NON-NLS-1$
	private static final String RSN_END_TAG = Messages.getString("DRDResponse_14");  //$NON-NLS-1$
	private static final String RSNTXT_START_TAG = Messages.getString("DRDResponse_15");  //$NON-NLS-1$
	private static final String RSNTXT_END_TAG = Messages.getString("DRDResponse_16");  //$NON-NLS-1$
	
	public static final String RET_ALL_OK = Messages.getString("DRDResponse_17");  //$NON-NLS-1$
	public static final String RSN_TXT_ALL_OK = Messages.getString("DRDResponse_18");  //$NON-NLS-1$
	public static final String RSN_TXT_WARN = Messages.getString("DRDResponse_19");  //$NON-NLS-1$
	
	public DRDResponse() {
		
		super();
	}
	
	public DRDResponse(String resp) {
	
		super();
		
		int pos1;
		int pos2;

		if (resp != null) {
			response = resp;

			//If we get valid XML returned then the response is the entire message we received.
			//
			//It's easier this way because theoretically other tags could be intermingled, so the processor of the response can
			//simply extract the XML fields it requires.
			pos1 = response.indexOf(RC_START_TAG);
			if (pos1 >= 0) {
				pos2 = response.indexOf(RC_END_TAG);
				returnCode = response.substring(pos1 + RC_START_TAG.length(), pos2);
			}	
			pos1 = response.indexOf(RSN_START_TAG);
			if (pos1 >= 0) {	
				pos2 = response.indexOf(RSN_END_TAG);
				reasonCode = response.substring(pos1 + RSN_START_TAG.length(), pos2);
			}
			pos1 = response.indexOf(RSNMSG_START_TAG);
			if (pos1 >= 0) {
				pos2 = response.indexOf(RSNMSG_END_TAG);
				reasonMsg = response.substring(pos1 + RSNMSG_START_TAG.length(), pos2);
			}
			pos1 = response.indexOf(RSNTXT_START_TAG);
			if (pos1 >= 0) {
				pos2 = response.indexOf(RSNTXT_END_TAG);
				reasonTxt = response.substring(pos1 + RSNTXT_START_TAG.length(), pos2);
			}
		}
	}
	
	public String getFieldValue(String fldName) {
		
		int pos;
		int valueStart;
		
		pos = response.indexOf(Messages.getString("DRDResponse_20") + fldName + Messages.getString("DRDResponse_21")); //$NON-NLS-1$ //$NON-NLS-2$
		if (pos >= 0) {
			valueStart = pos + fldName.length() + 2;
			return response.substring(valueStart, response.indexOf(Messages.getString("DRDResponse_22") + fldName + Messages.getString("DRDResponse_23"), valueStart));  //$NON-NLS-1$ //$NON-NLS-2$
		}
		else {
			return "";  //$NON-NLS-1$
		}
	}

	public String getResponse() {
		
		return response;
	}

	public String getReturnCode() {

		return returnCode;
	}

	public String getReasonCode() {
		
		return reasonCode;
	}
	
	public String getReasonMsgTxt() {
		return (reasonMsg + " " + reasonTxt).trim();  //$NON-NLS-1$
	}

	public Xheader getXhdr() {
		return xhdr;
	}

	public void setXhdr(Xheader xhdr) {
		this.xhdr = xhdr;
	}
}
