package com.fundi.framework.common.helpers;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

import java.util.ArrayList;
import java.util.Collections;

import com.fundi.framework.common.displaylist.DisplayList;
import com.fundi.framework.common.displaylist.ListField;
import com.fundi.framework.common.displaylist.ListFieldDefn;
import com.fundi.framework.common.displaylist.ListFilter;
import com.fundi.framework.common.displaylist.ListFilterCondition;
import com.fundi.framework.common.displaylist.ListRow;
import com.fundi.framework.common.displaylist.SummaryGroup;
import com.fundi.framework.common.instance.AppInstance;
import com.fundi.framework.common.nl1.Messages;

public class ListSummaryHelper {

	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$
	
	private AppInstance instance;
	private DisplayList list;
	
	private ListFilter filter = null;
	
	private ArrayList<ListFilter> originalFilters = new ArrayList<ListFilter>();
	private boolean highlightingOnly = false;
	
	private ArrayList<ListFilter> filters;
	
	public ListSummaryHelper(AppInstance instance, DisplayList list) {

		super();
		
		this.instance = instance;
		this.list = list;
		
		originalFilters = (ArrayList<ListFilter>) list.getCurrentFilters().clone();
		highlightingOnly = list.isHighlightingOnly();
	}
	
	public DisplayList getList() {
		
		return list;
	}
	
	public ArrayList<SummaryGroup> getSummaryGroups(ArrayList<String> fieldLabels, boolean caseSensitive) {
		
		ArrayList<SummaryGroup> groups = new ArrayList<SummaryGroup>();
		int idxGrp;
		SummaryGroup group;
		int idxRow;
		int idxLbl;
		ArrayList<ListRow> rows = list.getVisibleRows();
		String[] values = new String[fieldLabels.size()];
		ListRow row;
		ListField field;
		
		for (idxRow = 0; idxRow < rows.size(); idxRow++) {
			row = rows.get(idxRow);
			if (!row.isBlankRow()) {
				for (idxLbl = 0; idxLbl < fieldLabels.size(); idxLbl++) {
					field = row.getField(fieldLabels.get(idxLbl));
					if (field != null) {
						if (field.getValue() != null) {
							values[idxLbl] = field.getValue();
							if (!caseSensitive) {
								values[idxLbl] = values[idxLbl].toUpperCase();
							}
						}
						else {
							values[idxLbl] = "";
						}
					}
					else {
						values[idxLbl] = "";
					}
				}
				group = new SummaryGroup(values);
				idxGrp = groups.indexOf(group);
				if (idxGrp >= 0) {
					groups.get(idxGrp).incrementCount();
				}
				else {
					groups.add(new SummaryGroup(values.clone()));
				}
			}
		}
		
		Collections.sort(groups);
		
		return groups;
	}
	
	public void createSummaryFilter() {
		
		filters = (ArrayList<ListFilter>) originalFilters.clone();
		
		removeSummaryFilter();

		filter = new ListFilter();
		filter.setActive(true);
		filter.setSummary(true);
		filters.add(filter);
	}

	public void addFilterCondition(String fieldLabel, String value, boolean caseSensitive) {
		
		if (filter != null) {
			filter.addCondition(list.getFieldDefn(fieldLabel), ListFilterCondition.opEquals, value, false, 0,0,0, caseSensitive);
		}
	}
	
	public ArrayList<ListFilter> getFilters() {
		
		return filters;
	}
	
	public void removeSummaryFilter() {
		
		filters = (ArrayList<ListFilter>) originalFilters.clone();
	}
	
	private ListFieldDefn getFieldDefinition(DisplayList list, String label) {
		
		int idxDefn;
		ListFieldDefn defn;
		
		for (idxDefn = 0; idxDefn < list.getFieldDefns().size(); idxDefn++) {
			defn = list.getFieldDefns().get(idxDefn);
			if (defn.getLabel().equalsIgnoreCase(label)) {
				return defn;
			}
		}
		
		return null;
	} 
	
	public void clearConditions(ListFilter filter) {
		
		filter.clearConditions();
	}
	
	public void addCondition(ListFilter filter, DisplayList list, ListFilterCondition originalCondition, String field, String operator, String enteredValue,
												boolean highlight, int red, int green, int blue, boolean caseSensitive) {
		
		ListFieldDefn defn = getFieldDefinition(list, field);
		
		if (defn == null) {
			defn = originalCondition.getFieldDefn();
		}
		
		filter.addCondition(defn, operator, enteredValue, highlight, red, green, blue, caseSensitive);
	}
}
