package com.fundi.framework.common.navigation;

/*
 *  Common Services Library - Framework plug-in.
 *  (C) Copyright Fundi Software 2011, 2016.  Fundi Confidential.
 *  All rights reserved.  Use, duplication or disclosure restricted. 
 */

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;

import com.fundi.framework.common.nl1.Messages;

public class SerializableNavigationItem implements Serializable {

	//Eye catchers.
	public static final String EC_COPYRIGHT = "(C) Copyright 2011, 2016 Fundi Software.  Fundi Confidential."; //$NON-NLS-1$
	public static final String EC_APAR = "3.1.1.00_00014"; //$NON-NLS-1$
	public static final String EC_FMID = "H30SA10"; //$NON-NLS-1$
	public static final String EC_PID = "5655-CSL"; //$NON-NLS-1$

	private static final long serialVersionUID = 1L;
	
	private boolean group = false;
	private boolean expanded = false;
	private boolean opened = false;
	private String displayCaption = ""; //$NON-NLS-1$
	private String fullTitle = ""; //$NON-NLS-1$
	private String dataClassName = "";  //The class.getName() of the originating object. //$NON-NLS-1$
	
	private ArrayList<SerializableNavigationItem> subItems = new ArrayList<SerializableNavigationItem>();
	
	public SerializableNavigationItem() {
		
		super();
	}

	public boolean isGroup() {
		
		return group;
	}

	public void setGroup(boolean group) {
		
		this.group = group;
	}

	public boolean isExpanded() {
		
		return expanded;
	}

	public void setExpanded(boolean expanded) {
		
		this.expanded = expanded;
	}

	public boolean isOpened() {
		
		return opened;
	}

	public void setOpened(boolean opened) {
		
		this.opened = opened;
	}

	public String getDisplayCaption() {
		
		return displayCaption;
	}
	
	public String getFullTitle() {
		
		return fullTitle;
	}

	public void setDisplayCaption(String displayCaption) {
		
		this.displayCaption = displayCaption;
	}
	
	public void setFullTitle(String fullTitle) {
		
		this.fullTitle = fullTitle;
	}

	public String getDataClassName() {
		
		return dataClassName;
	}

	public void setDataClassName(String dataClassName) {
		
		this.dataClassName = dataClassName;
	}
	
	public void addSubItem(SerializableNavigationItem item) {
		
		Iterator<SerializableNavigationItem> itSub;
		boolean found = false;
		
		for (itSub = subItems.iterator(); itSub.hasNext();) {
			if (itSub.next().equals(item)) {
				found = true;
				break;
			}
		}
		
		if (!found) {
			subItems.add(item);
			setGroup(true);
		}
	}
	
	public ArrayList<SerializableNavigationItem> getSubItems() {
		
		return subItems;
	}
	
	public void removeAllSubItems() {
		
		subItems.clear();
	}
	
	public void removeSubItem(SerializableNavigationItem subItem) {

		subItems.remove(subItem);
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((dataClassName == null) ? 0 : dataClassName.hashCode());
		result = prime * result
				+ ((displayCaption == null) ? 0 : displayCaption.hashCode());
		result = prime * result
				+ ((fullTitle == null) ? 0 : fullTitle.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		SerializableNavigationItem other = (SerializableNavigationItem) obj;
		if (dataClassName == null) {
			if (other.dataClassName != null)
				return false;
		} else if (!dataClassName.equals(other.dataClassName))
			return false;
		if (displayCaption == null) {
			if (other.displayCaption != null)
				return false;
		} else if (!displayCaption.equals(other.displayCaption))
			return false;
		if (fullTitle == null) {
			if (other.fullTitle != null)
				return false;
		} else if (!fullTitle.equals(other.fullTitle))
			return false;
		return true;
	}
}
